@@ -39,7 +39,7 @@ public:
     File(File &&) = default;
     File &operator=(File &&) = default;
 
-    QString segment() const
+    [[nodiscard]] QString segment() const
     {
         return m_segment;
     }
@@ -65,7 +65,7 @@ public:
         m_name = newName;
     }
     /** Decoded name. Use when you need a QString. */
-    QString decodedName() const
+    [[nodiscard]] QString decodedName() const
     {
         return QString::fromUtf8(m_name);
     }
@@ -73,9 +73,9 @@ public:
      * Human readable name (including native separators where applicable).
      * Only use for display.
      */
-    QString displayName() const;
+    [[nodiscard]] QString displayName() const;
 
-    FileSize size() const
+    [[nodiscard]] FileSize size() const
     {
         return m_size;
     }
@@ -89,14 +89,14 @@ public:
      * Human readable path for display (including native separators where applicable.
      * Only use for display.
      */
-    QString displayPath(const std::shared_ptr<Folder> &root = {}) const;
-    QString humanReadableSize() const
+    [[nodiscard]] QString displayPath(const std::shared_ptr<Folder> &root = {}) const;
+    [[nodiscard]] QString humanReadableSize() const
     {
         return KFormat().formatByteSize(m_size);
     }
 
     /** Builds a complete QUrl by walking up to root. */
-    QUrl url(const std::shared_ptr<Folder> &root = {}) const;
+    [[nodiscard]] QUrl url(const std::shared_ptr<Folder> &root = {}) const;
 
 protected:
     File(const char *name, FileSize size, Folder *parent)
@@ -127,11 +127,11 @@ public:
     Folder(Folder &&) = default;
     Folder &operator=(Folder &&) = default;
 
-    uint children() const
+    [[nodiscard]] uint children() const
     {
         return m_children;
     }
-    bool isFolder() const override
+    [[nodiscard]] bool isFolder() const override
     {
         return true;
     }
